/*
 *  lve.h
 *
 *  Copyright (C) Gerhard Monzel - October 2003
 *
 *  This file is part of lve, a linux mpeg video editor
 *      
 *  lve tools are free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *   
 *  lve is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *   
 *  You should have received a copy of the GNU General Public License
 *  along with GNU Make; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */
#ifndef _LVE_H
#define _LVE_H 1

#include <SDL/SDL.h>
#include "lve_ctx.h"
#include "mediafile.h"

//-- default path + names --
#define PATH_LIB	"/usr/local/lve/lib/"
#define PATH_BIN	"/usr/local/lve/bin/"
#define FN_SCREEN_BMP	"lve.bmp"

//-- qdir modes + filters --
#define QDIR_OPEN  0
#define QDIR_SAVE  1
#define QDIR_NEW   2

#define QDIR_MD      " 0"
#define QDIR_MD_LST  " 1"
#define QDIR_ED_PRJ  " 2"

//-- player functions (actions) --
#define A_NOMEDIA 0
#define A_QUIT    1
#define A_PLAY    2
#define A_STOP    3
#define A_JUMP    4
#define A_SPLIT   5
#define A_SLIDE   6
#define A_ATRACK  7
#define A_ASW     8

//-- player speeds (intervals) --
#define IV_START  200
#define IV_NORM   (1000/25)
#define IV_FAST	  (IV_NORM/2)
#define IV_SLOW   (IV_NORM*2)

//-- stepwide -- 
#define STEP0WIDE   5   // little step for/back (frames) 
#define STEP1WIDE  25   // normal step for/back (frames)
#define STEP2WIDE  50   // big step for/back (frames)
#define STEPTOEOF   3   // secure position bevor eof (frames)

#undef __EXTERN
#ifndef _LVE_
#define __EXTERN extern
#else
#define __EXTERN
#endif

__EXTERN void   lve_close_mdf(TMediaFile *mdf); 
__EXTERN int    lve_load_mdf(T_LVE_CTX  *ctx, TMediaFile *mdf = NULL);
__EXTERN void   lve_cleanup_media(T_LVE_CTX *ctx);
__EXTERN char  *lve_fselect_media(int mode, char *filter);
__EXTERN void   lve_decoder_switch_lock(int sw);
__EXTERN void   lve_set_avs(int dp);
__EXTERN void   lve_reset_lists(T_LVE_CTX *ctx);

#endif // _LVE_H
